@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -64,7 +64,8 @@ class DirScanner(threading.Thread):
     def __init__(self):
         super().__init__()
 
-        self.loop: Optional[asyncio.AbstractEventLoop] = None
+        # Create loop right away, so socks5 proxy doesn't break it
+        self.loop = asyncio.new_event_loop()
         self.scanner_task: Optional[asyncio.Task] = None
         self.lock: Optional[asyncio.Lock] = None  # Prevents concurrent scans
         self.error_reported = False  # Prevents multiple reporting of missing watched folder
@@ -78,7 +79,7 @@ class DirScanner(threading.Thread):
             if dirscan_dir != self.dirscan_dir:
                 self.ignored = {}
                 self.suspected = {}
-        except:
+        except Exception:
             self.ignored = {}  # Will hold all unusable files and the
             # successfully processed ones that cannot be deleted
             self.suspected = {}  # Will hold name/attributes of suspected candidates
@@ -109,8 +110,6 @@ class DirScanner(threading.Thread):
     def run(self):
         """Start the scanner"""
         logging.info("Dirscanner starting up")
-        self.loop = asyncio.new_event_loop()
-
         try:
             self.start_scanner()
             self.loop.run_forever()
@@ -158,7 +157,7 @@ class DirScanner(threading.Thread):
                             # https://docs.python.org/3/library/os.html#os.DirEntry.stat
                             # On Windows, the st_ino, st_dev and st_nlink attributes of the stat_result are always set
                             # to zero. Call os.stat() to get these attributes.
-                            if sabnzbd.WIN32:
+                            if sabnzbd.WINDOWS:
                                 stat_tuple = os.stat(path)
                             else:
                                 stat_tuple = entry.stat()
@@ -175,7 +174,7 @@ class DirScanner(threading.Thread):
                             del self.suspected[path]
 
                     yield path, catdir, stat_tuple
-        except:
+        except Exception:
             if not self.error_reported and not catdir:
                 logging.error(T("Cannot read Watched Folder %s"), filesystem.clip_path(folder))
                 logging.info("Traceback: ", exc_info=True)
