@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@ import time
 import re
 import gc
 import queue
+import rarfile
 from typing import List, Optional, Tuple
 
 import sabnzbd
@@ -42,11 +43,11 @@ from threading import Thread
 from sabnzbd.misc import (
     on_cleanup_list,
     is_sample,
-    helpful_warning,
     history_updated,
     change_queue_complete_action,
     run_script,
     is_none,
+    SABRarFile,
 )
 from sabnzbd.filesystem import (
     real_path,
@@ -71,8 +72,6 @@ from sabnzbd.filesystem import (
     get_unique_filename,
     get_ext,
     get_filename,
-    directory_is_writable,
-    check_filesystem_capabilities,
 )
 from sabnzbd.nzbstuff import NzbObject
 from sabnzbd.sorting import Sorter
@@ -92,7 +91,6 @@ import sabnzbd.config as config
 import sabnzbd.cfg as cfg
 import sabnzbd.database as database
 import sabnzbd.notifier as notifier
-import sabnzbd.utils.rarfile as rarfile
 import sabnzbd.utils.rarvolinfo as rarvolinfo
 import sabnzbd.utils.checkdir
 import sabnzbd.deobfuscate_filenames as deobfuscate
@@ -150,7 +148,7 @@ class PostProcessor(Thread):
                 logging.warning(T("Old queue detected, use Status->Repair to convert the queue"))
             elif isinstance(history_queue, list):
                 self.history_queue = [nzo for nzo in history_queue if os.path.exists(nzo.download_path)]
-        except:
+        except Exception:
             logging.info("Corrupt %s file, discarding", POSTPROC_QUEUE_FILE_NAME)
             logging.info("Traceback: ", exc_info=True)
 
@@ -186,7 +184,7 @@ class PostProcessor(Thread):
         """Remove given nzo from the queue"""
         try:
             self.history_queue.remove(nzo)
-        except:
+        except Exception:
             pass
         self.save()
         history_updated()
@@ -209,7 +207,7 @@ class PostProcessor(Thread):
                         # Try to kill any external running process
                         self.external_process.kill()
                         logging.info("Killed external process %s", self.external_process.args[0])
-                    except:
+                    except Exception:
                         pass
                 result = True
             return result
@@ -234,7 +232,7 @@ class PostProcessor(Thread):
             search_text = search.strip().replace("*", ".*").replace(" ", ".*") + ".*?"
             try:
                 re_search = re.compile(search_text, re.I)
-            except:
+            except Exception:
                 logging.error(T("Failed to compile regex for search term: %s"), search_text)
 
         # Need a copy to prevent race conditions
@@ -262,25 +260,6 @@ class PostProcessor(Thread):
 
     def run(self):
         """Postprocessor loop"""
-        # First we do a dircheck
-        complete_dir = sabnzbd.cfg.complete_dir.get_path()
-        if sabnzbd.utils.checkdir.isFAT(complete_dir):
-            helpful_warning(
-                T("Completed Download Folder %s is on FAT file system, limiting maximum file size to 4GB")
-                % complete_dir
-            )
-        else:
-            logging.debug("Completed Download Folder %s is not on FAT", complete_dir)
-
-        if directory_is_writable(sabnzbd.cfg.download_dir.get_path()):
-            check_filesystem_capabilities(sabnzbd.cfg.download_dir.get_path())
-        if directory_is_writable(sabnzbd.cfg.complete_dir.get_path()):
-            check_filesystem_capabilities(sabnzbd.cfg.complete_dir.get_path())
-
-        # Do an extra purge of the history on startup to ensure timely removal on systems that
-        # aren't on 24/7 and typically don't benefit from the daily scheduled call at midnight
-        database.scheduled_history_purge()
-
         # Start looping
         check_eoq = False
         while not self.__stop:
@@ -536,7 +515,7 @@ def process_job(nzo: NzbObject) -> bool:
 
                 try:
                     newfiles = rename_and_collapse_folder(tmp_workdir_complete, workdir_complete, newfiles)
-                except:
+                except Exception:
                     logging.error(
                         T('Error renaming "%s" to "%s"'),
                         clip_path(tmp_workdir_complete),
@@ -638,7 +617,7 @@ def process_job(nzo: NzbObject) -> bool:
         # See if we need to start an alternative or remove the duplicates
         sabnzbd.NzbQueue.handle_duplicate_alternatives(nzo, all_ok)
 
-    except:
+    except Exception:
         logging.error(T("Post Processing Failed for %s (%s)"), filename, T("see logfile"))
         logging.info("Traceback: ", exc_info=True)
 
@@ -672,7 +651,7 @@ def process_job(nzo: NzbObject) -> bool:
     # Clean up the NZO data
     try:
         nzo.purge_data(delete_all_data=all_ok)
-    except:
+    except Exception:
         logging.error(T("Cleanup of %s failed."), nzo.final_name)
         logging.info("Traceback: ", exc_info=True)
 
@@ -765,7 +744,7 @@ def prepare_extraction_path(nzo: NzbObject) -> Tuple[str, str, Sorter, bool, Opt
 
         try:
             renamer(workdir_complete, tmp_workdir_complete)
-        except:
+        except Exception:
             pass  # On failure, just use the original name
 
         # Is the unique path different? Then we also need to modify the final path
@@ -914,7 +893,7 @@ def try_rar_check(nzo: NzbObject, rars: List[str]) -> bool:
         nzo.set_action_line(T("Trying RAR-based verification"), "...")
         try:
             # Requires de-unicode for RarFile to work!
-            zf = rarfile.RarFile(rars[0])
+            zf = SABRarFile(rars[0])
 
             # Skip if it's encrypted
             if zf.needs_password():
@@ -969,9 +948,13 @@ def rar_renamer(nzo: NzbObject) -> int:
         if not os.path.isfile(file_to_check):
             continue
 
+        # guard against cbr files due to pr#3114
+        if get_ext(file_to_check) == ".cbr":
+            continue
+
         if rarfile.is_rarfile(file_to_check):
-            # if a rar file is fully encrypted, rarfile.RarFile() will return an empty list:
-            if not rarfile.RarFile(file_to_check, single_file_check=True).filelist():
+            # if a rar file is fully encrypted, RarFile() will return an empty list:
+            if not SABRarFile(file_to_check, part_only=True).filelist():
                 logging.info(
                     "Download %s contains a fully encrypted & obfuscated rar-file: %s.",
                     nzo.final_name,
@@ -987,12 +970,10 @@ def rar_renamer(nzo: NzbObject) -> int:
             logging.debug("Detected volume-number %s from RAR-header: %s ", rar_vol, file_to_check)
             volnrext[file_to_check] = (rar_vol, new_extension)
             # The files inside rar file
-            rar_contents = rarfile.RarFile(
-                os.path.join(nzo.download_path, file_to_check), single_file_check=True
-            ).filelist()
+            rar_contents = SABRarFile(os.path.join(nzo.download_path, file_to_check), part_only=True).filelist()
             try:
                 rarvolnr[rar_vol]
-            except:
+            except Exception:
                 # does not yet exist, so create:
                 rarvolnr[rar_vol] = {}
             rarvolnr[rar_vol][file_to_check] = rar_contents  # store them for matching (if needed)
@@ -1035,7 +1016,7 @@ def rar_renamer(nzo: NzbObject) -> int:
     for rar_set_number in range(1, highest_rar + 1):
         try:
             how_many_here = len(rarvolnr[rar_set_number])
-        except:
+        except Exception:
             # rarset does not exist at all
             logging.warning("rarset %s is missing completely, so I can't deobfuscate.", rar_set_number)
             return 0
@@ -1136,10 +1117,10 @@ def cleanup_list(wdir: str, skip_nzb: bool):
                             try:
                                 logging.info("Removing unwanted file %s", entry.path)
                                 remove_file(entry.path)
-                            except:
+                            except Exception:
                                 logging.error(T("Removing %s failed"), clip_path(entry.path))
                                 logging.info("Traceback: ", exc_info=True)
-        except:
+        except Exception:
             logging.info("Traceback: ", exc_info=True)
 
 
@@ -1233,7 +1214,7 @@ def remove_samples(path: str):
             try:
                 logging.info("Removing unwanted sample file %s", path)
                 remove_file(path)
-            except:
+            except Exception:
                 logging.error(T("Removing %s failed"), clip_path(path))
                 logging.info("Traceback: ", exc_info=True)
     else:
@@ -1261,7 +1242,7 @@ def rename_and_collapse_folder(oldpath: str, newpath: str, files: List[str]) ->
     renamer(oldpath, newpath)
     try:
         remove_dir(orgpath)
-    except:
+    except Exception:
         pass
     return files
 
@@ -1274,7 +1255,7 @@ def set_marker(folder: str) -> Optional[str]:
         try:
             fp = open(path, "w")
             fp.close()
-        except:
+        except Exception:
             logging.info("Cannot create marker file %s", path)
             logging.info("Traceback: ", exc_info=True)
             name = None
@@ -1287,7 +1268,7 @@ def del_marker(path: str):
         logging.debug("Removing marker file %s", path)
         try:
             remove_file(path)
-        except:
+        except Exception:
             logging.info("Cannot remove marker file %s", path)
             logging.info("Traceback: ", exc_info=True)
 
