@@ -89,7 +89,7 @@ class RSSReader:
             if self.jobs:
                 for feed in self.jobs:
                     remove_obsolete(self.jobs[feed], list(self.jobs[feed]))
-        except:
+        except Exception:
             logging.warning(T("Cannot read %s"), RSS_FILE_NAME)
             logging.info("Traceback: ", exc_info=True)
 
@@ -479,7 +479,7 @@ class RSSReader:
         if feed in self.jobs:
             try:
                 return self.jobs[feed]
-            except:
+            except Exception:
                 return {}
         else:
             return {}
@@ -649,19 +649,26 @@ def _get_link(entry):
     """Retrieve the post link from this entry
     Returns (link, category, size)
     """
+    link = None
     size = 0
     age = datetime.datetime.now()
 
     # Try standard link and enclosures first
-    link = entry.link
-    if not link:
-        link = entry.links[0].href
-    if "enclosures" in entry:
+    if "enclosures" in entry and entry["enclosures"]:
         try:
-            link = entry.enclosures[0]["href"]
-            size = int(entry.enclosures[0]["length"])
-        except:
+            for enclosure in entry["enclosures"]:
+                if "type" in enclosure and enclosure["type"] != "application/x-nzb":
+                    continue
+
+                link = enclosure["href"]
+                size = int(enclosure["length"])
+                break
+        except Exception:
             pass
+    else:
+        link = entry.link
+        if not link:
+            link = entry.links[0].href
 
     # GUID usually has URL to result on page
     infourl = None
@@ -675,19 +682,19 @@ def _get_link(entry):
             m = _RE_SIZE1.search(desc) or _RE_SIZE2.search(desc)
             if m:
                 size = from_units(m.group(1))
-        except:
+        except Exception:
             pass
 
     # Try newznab attribute first, this is the correct one
     try:
         # Convert it to format that calc_age understands
         age = datetime.datetime(*entry["newznab"]["usenetdate_parsed"][:6])
-    except:
+    except Exception:
         # Date from feed (usually lags behind)
         try:
             # Convert it to format that calc_age understands
             age = datetime.datetime(*entry.published_parsed[:6])
-        except:
+        except Exception:
             pass
     finally:
         # We need to convert it to local timezone, feedparser always returns UTC
@@ -717,7 +724,7 @@ def _get_link(entry):
 
         return link, infourl, category, size, age, season, episode
     else:
-        logging.warning(T("Empty RSS entry found (%s)"), link)
+        logging.info(T("Empty RSS entry found (%s)"), link)
         return None, None, "", 0, None, 0, 0
 
 
