@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2022 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -40,6 +40,7 @@ class Scheduler:
         self.scheduler = kronos.ThreadedScheduler()
         self.pause_end: Optional[float] = None  # Moment when pause will end
         self.resume_task: Optional[kronos.Task] = None
+        self.rss_task: Optional[kronos.Task] = None  # RSS interval task
         self.restart_scheduler = False
         self.pp_pause_event = False
         self.load_schedules()
@@ -85,10 +86,10 @@ class Scheduler:
 
             try:
                 enabled, m, h, d, action_name = schedule.split()
-            except:
+            except Exception:
                 try:
                     enabled, m, h, d, action_name, argument_list = schedule.split(None, 5)
-                except:
+                except Exception:
                     continue  # Bad schedule, ignore
 
             if argument_list:
@@ -98,7 +99,7 @@ class Scheduler:
             try:
                 m = int(m)
                 h = int(h)
-            except:
+            except Exception:
                 logging.warning(T("Bad schedule %s at %s:%s"), action_name, m, h)
                 continue
 
@@ -137,6 +138,8 @@ class Scheduler:
             elif action_name == "rss_scan":
                 action = sabnzbd.RSSReader.run
                 rss_planned = True
+            elif action_name == "create_backup":
+                action = sabnzbd.config.create_config_backup
             elif action_name == "remove_failed":
                 action = sabnzbd.api.history_remove_failed
             elif action_name == "remove_completed":
@@ -187,35 +190,53 @@ class Scheduler:
             delay = random.randint(0, interval - 1)
             logging.info("Scheduling RSS interval task every %s min (delay=%s)", interval, delay)
             sabnzbd.RSSReader.next_run = time.time() + delay * 60
-            self.scheduler.add_interval_task(sabnzbd.RSSReader.run, "RSS", delay * 60, interval * 60)
-            self.scheduler.add_single_task(sabnzbd.RSSReader.run, "RSS", 15)
+            self.rss_task = self.scheduler.add_interval_task(sabnzbd.RSSReader.run, "RSS", delay * 60, interval * 60)
 
         if cfg.version_check():
-            # Check for new release, once per week on random time
+            # Check for new release daily at a random time
             m = random.randint(0, 59)
             h = random.randint(0, 23)
-            d = (random.randint(1, 7),)
 
-            logging.info("Scheduling VersionCheck on day %s at %s:%s", d[0], h, m)
-            self.scheduler.add_daytime_task(sabnzbd.misc.check_latest_version, "VerCheck", d, None, (h, m))
+            logging.info("Scheduling version check in 10 minutes and daily at %s:%s", h, m)
+            self.scheduler.add_single_task(sabnzbd.misc.check_latest_version, "version_check", 10 * 60)
+            self.scheduler.add_daytime_task(
+                sabnzbd.misc.check_latest_version,
+                "recurring_version_check",
+                DAILY_RANGE,
+                None,
+                (h, m),
+            )
 
         action, hour, minute = sabnzbd.BPSMeter.get_quota()
         if action:
             logging.info("Setting schedule for quota check daily at %s:%s", hour, minute)
             self.scheduler.add_daytime_task(action, "quota_reset", DAILY_RANGE, None, (hour, minute))
 
-        if sabnzbd.misc.int_conv(cfg.history_retention()) > 0:
-            logging.info("Setting schedule for midnight auto history-purge")
-            self.scheduler.add_daytime_task(
-                sabnzbd.database.midnight_history_purge, "midnight_history_purge", DAILY_RANGE, None, (0, 0)
-            )
+        logging.info("Setting schedule for midnight auto history-purge")
+        self.scheduler.add_daytime_task(
+            sabnzbd.database.scheduled_history_purge,
+            "midnight_history_purge",
+            DAILY_RANGE,
+            None,
+            (0, 0),
+        )
 
         logging.info("Setting schedule for midnight BPS reset")
-        self.scheduler.add_daytime_task(sabnzbd.BPSMeter.update, "midnight_bps", DAILY_RANGE, None, (0, 0))
-
-        logging.info("Setting schedule for server expiration check")
         self.scheduler.add_daytime_task(
-            sabnzbd.downloader.check_server_expiration, "check_server_expiration", DAILY_RANGE, None, (0, 0)
+            sabnzbd.BPSMeter.update,
+            "midnight_bps",
+            DAILY_RANGE,
+            None,
+            (0, 0),
+        )
+
+        logging.info("Setting schedule for midnight server expiration check")
+        self.scheduler.add_daytime_task(
+            sabnzbd.downloader.check_server_expiration,
+            "check_server_expiration",
+            DAILY_RANGE,
+            None,
+            (0, 0),
         )
 
         logging.info("Setting schedule for server quota check")
@@ -253,7 +274,7 @@ class Scheduler:
             action = ev[1]
             try:
                 value = ev[2]
-            except:
+            except Exception:
                 value = None
             if action == "pause":
                 paused = True
@@ -290,12 +311,12 @@ class Scheduler:
             elif action == "enable_server":
                 try:
                     servers[value] = 1
-                except:
+                except Exception:
                     logging.warning(T("Schedule for non-existing server %s"), value)
             elif action == "disable_server":
                 try:
                     servers[value] = 0
-                except:
+                except Exception:
                     logging.warning(T("Schedule for non-existing server %s"), value)
 
         # Special case, a priority was passed, so evaluate only that and return state
@@ -329,7 +350,7 @@ class Scheduler:
                 if bool(item.enable()) != bool(value):
                     item.enable.set(value)
                     sabnzbd.Downloader.init_server(serv, serv)
-            except:
+            except Exception:
                 pass
         config.save_config()
 
@@ -428,8 +449,15 @@ class Scheduler:
         self.scheduler.add_single_task(action, "", interval * 60, args=parms)
 
     def force_rss(self):
-        """Add a one-time RSS scan, one second from now"""
-        self.scheduler.add_single_task(sabnzbd.RSSReader.run, "RSS", 1)
+        """Run RSS scan immediately and reschedule interval task"""
+        # Cancel the current RSS interval task
+        if self.rss_task:
+            self.scheduler.cancel(self.rss_task)
+
+        # Schedule a new interval task and start one now
+        interval = cfg.rss_rate() * 60  # Convert minutes to seconds
+        sabnzbd.RSSReader.next_run = time.time() + interval
+        self.rss_task = self.scheduler.add_interval_task(sabnzbd.RSSReader.run, "RSS", 0, interval)
 
 
 def sort_schedules(all_events, now=None):
@@ -452,10 +480,10 @@ def sort_schedules(all_events, now=None):
         try:
             # Note: the last parameter can have spaces (category name)!
             enabled, m, h, dd, action, parms = schedule.split(None, 5)
-        except:
+        except Exception:
             try:
                 enabled, m, h, dd, action = schedule.split(None, 4)
-            except:
+            except Exception:
                 continue  # Bad schedule, ignore
         action = action.strip()
         if dd == "*":
@@ -489,7 +517,7 @@ def enable_server(server):
     """Enable server (scheduler only)"""
     try:
         config.get_config("servers", server).enable.set(1)
-    except:
+    except Exception:
         logging.warning(T("Trying to set status of non-existing server %s"), server)
         return
     config.save_config()
@@ -500,7 +528,7 @@ def disable_server(server):
     """Disable server (scheduler only)"""
     try:
         config.get_config("servers", server).enable.set(0)
-    except:
+    except Exception:
         logging.warning(T("Trying to set status of non-existing server %s"), server)
         return
     config.save_config()
